Description Usage Arguments Details Value Author(s) See Also
Create an Excel File and Worksheet Tibble
1 | .create_excel_ws_ls(folder_path, recurse = TRUE)
|
folder_path |
Required. A path to the folder with Excel files you want data on. |
recurse |
Optional. If |
Creates a tibble of information on all Excel (".xls" or ".xlsx") files found in a provided folder path.
Returns a tibble with the following columns of data on all ".xls" or ".xlsx" files found at the provided path:
path: A
full path to each Excel file found at the provided folder path.
folder_path: The folder path the Excel file was found in.
file_name: The Excel file name (with extention) found in the folder.
worksheet_title: The title of each worksheet in the Excel
file.
Daniel Germony daniel.r.germony.civ@mail.mil
.import_excel_ws_ls() for how to import worksheets identfied in
the tibble created with this function.
.grab_cell() pulls the value out of an individual Excel cell and
reurns it to R.
Other dstCSDR Import Excel Data Functions: .grab_cell,
.import_excel_ws_ls
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.